"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parsePage = void 0;
var assertOk = function (ok, message) {
    if (!ok) {
        throw new Error(message);
    }
};
var parsePage = function (window) {
    var _a;
    var page = window.document.querySelector("#a-page");
    var title = page.querySelector("h3.kp-notebook-metadata");
    var coverImage = page.querySelector(".kp-notebook-cover-image-border");
    var asinNode = page.querySelector("#kp-notebook-annotations-asin");
    var asinValue = asinNode.value;
    assertOk(coverImage, "coverImage not found");
    assertOk(asinNode, "ASIN not found");
    assertOk(title, "title not found");
    var annotationNodes = page.querySelectorAll("#kp-notebook-annotations > div.a-row");
    assertOk(annotationNodes.length > 0, "annotations not found");
    var annotations = Array.from(annotationNodes)
        .filter(function (annotation) {
        return annotation.getAttribute("id") !== "empty-annotations-pane";
    })
        .map(function (annotation) {
        var noteNode = annotation.querySelector("[id=\"note\"]");
        var noteValue = noteNode && noteNode.textContent ? noteNode.textContent : undefined;
        var locationNode = annotation.querySelector("[id=\"kp-annotation-location\"]");
        assertOk(locationNode, "locationNode is not found");
        var highlightNode = annotation.querySelector("[id=\"highlight\"]");
        assertOk(highlightNode, "highlightNode is not found");
        var locationNumber = Number(locationNode.value);
        return {
            note: noteValue,
            locationNumber: locationNumber,
            highlight: highlightNode.textContent,
            kindleUrl: "kindle://book?action=open&asin=".concat(asinValue, "&location=").concat(locationNumber)
        };
    });
    return {
        title: (_a = title.textContent) === null || _a === void 0 ? void 0 : _a.trim(),
        coverImageUrl: coverImage.src,
        asin: asinValue,
        url: "https://www.amazon.co.jp/dp/".concat(asinValue),
        annotations: annotations
    };
};
exports.parsePage = parsePage;
//# sourceMappingURL=parse.js.map